@@ -2,12 +2,33 @@ from enum import auto
 from typing import List
 
 from jsonrpcclient.clients.http_client import HTTPClient
+from jsonrpcclient.exceptions import ReceivedErrorResponseError
 
 from common.cs_enum import AutoName
 
 DEFAULT_LEDGER_BOOK_ID = "1"
 
 
+class LedgerException(Exception):
+    def __init__(self, code, message):
+        self.code = code
+        self.message = message
+
+
+class LedgerInternalError(LedgerException):
+    pass
+
+
+class LedgerNotFoundError(LedgerException):
+    pass
+
+
+ERROR_CODES = {
+    404: LedgerNotFoundError,
+    500: LedgerInternalError,
+}
+
+
 class OperationType(AutoName):
     TRANSFER = auto()
 
@@ -24,7 +45,10 @@ class LedgerClient:
         self.rpc_client = HTTPClient(ledger_host)
 
     def _execute(self, method: str, *args):
-        rpc_response = self.rpc_client.request(method, *args)
+        try:
+            rpc_response = self.rpc_client.request(method, *args)
+        except ReceivedErrorResponseError as e:
+            raise ERROR_CODES.get(e.response.code, LedgerException)(e.response.code, e.response.message)
         return rpc_response.data.result
 
     def create_book(self, name: str, min_balance: str = None, metadata: dict = None):
